@@ -88,11 +88,11 @@ class WebHookTextBot:
             response: Dict[str, Any] = {
                 'statusCode': 200,
                 'headers': {'Content-Type': 'application/json'},
-                'body': {
+                'body': json.dumps({
                     'method': 'sendMessage',
-                    'text': json.dumps(text),
+                    'text': text,
                     'chat_id': self.input_message.chat_id
-                }
+                })
             }
 
             # Add reply_to_message_id key-value in case is specified by the user provided function
